@@ -40,13 +40,11 @@ class MysqlOperator(object):
         """
 
         chunks = [values[i : i + chunk_size] for i in range(0, len(values), chunk_size)]
-        self.logger.debug(f"Chunk size is {chunk_size}.")
         with self.Session.begin() as session:
             i = 0
             for chunk in chunks:
                 i += 1
                 upsert(values=chunk, session=session, table_name=table_name)
-                self.logger.debug(f"Chunk {i} uploaded")
         self.logger.info("Data uploaded to MySql.")
 
     def delete(
@@ -74,7 +72,6 @@ class MysqlOperator(object):
         )
         with self.Session.begin() as session:
             session.execute(sql)
-            self.logger.debug(f"The below sql statement is executed \n {sql}")
 
     def select_all(
         self,
@@ -108,8 +105,6 @@ class MysqlOperator(object):
                 result = pd.read_sql(sql, session.bind)
             else:
                 result = session.execute(sql).fetchall()
-        self.logger.debug(f"The below sql statement is executed \n {sql}")
-        self.logger.debug(f"Number of records retrieved = {str(len(result))}")
         return result
 
     def select(
@@ -147,8 +142,6 @@ class MysqlOperator(object):
             else:
                 result = session.execute(sql).fetchall()
 
-        self.logger.debug(f"The below sql statement is executed \n {sql}")
-        self.logger.debug(f"Number of records retrieved = {str(len(result))}")
         return result
 
     def get_row_count(
@@ -172,7 +165,6 @@ class MysqlOperator(object):
             where_statement=where_statement,
         )
         with self.Session.begin() as session:
-            self.logger.debug(f"The below sql statement will be executed: \n {sql}")
             cursor = session.execute(sql)
             row_count = cursor.fetchone()[0]
             self.logger.info("The sql statement is executed successfully\n")
